@@ -3,7 +3,7 @@
 
 # defaults.
 import os,sys,json,pathlib,platform
-def __get_argument__(argument, required=True, index=1, empty=None):
+def __get_argument__(argument, required=True, index=1, default=None):
 
 	# check presence.
 	if argument not in sys.argv:
@@ -26,7 +26,7 @@ def __get_argument__(argument, required=True, index=1, empty=None):
 	return empty
 def __get_operating_system__():
 	os = platform.system().lower()
-	if os in ["darwin"]: return "osx"
+	if os in ["darwin"]: return "macos"
 	elif os in ["linux"]: return "linux"
 	else: raise ValueError(f"Unsupported operating system: [{os}].")
 def __check_alias__(
@@ -81,9 +81,9 @@ try:
 except ImportError as e:
 	import os
 	if os.path.exists("/usr/bin/pip3"): 
-		os.system(f"/usr/bin/pip3 install -r {__get_source_path__(__file__, back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
+		os.system(f"/usr/bin/pip3 install -r {Formats.FilePath(__file__).base(back=3)}/requirements/requirements.txt --user {os.environ.get('USER')}")
 	else:
-		os.system(f"pip3 install -r {__get_source_path__(__file__, back=3)}/requirements/requirements.txt")
+		os.system(f"pip3 install -r {Formats.FilePath(__file__).base(back=3)}/requirements/requirements.pip")
 
 	# pip imports.
 	import os, sys, requests, ast, json, pathlib, glob, platform, subprocess, time, random, threading, urllib, flask, logging, multiprocessing
@@ -93,7 +93,6 @@ except ImportError as e:
 	from fil3s import Files, Formats
 	from r3sponse import r3sponse
 
-
 # universal variables.
 USER = os.environ.get("USER")
 OWNER = os.environ.get("USER")
@@ -101,7 +100,7 @@ GROUP = "root"
 HOME_BASE = "/home/"
 HOME = f"/home/{os.environ.get('USER')}/"
 MEDIA = f"/media/{os.environ.get('USER')}/"
-if OS in ["osx"]: 
+if OS in ["macos"]: 
 	HOME_BASE = "/Users/"
 	HOME = f"/Users/{os.environ.get('USER')}/"
 	MEDIA = f"/Volumes/"
