@@ -7,6 +7,7 @@ from syst3m.classes.color import color
 _input_ = input
 def input(message, yes_no=False):
 	if len(message) > 0 and message[0].upper() != message[0]: message = Formats.String(message).capitalized_word()
+	msg = color.fill(message)
 	if yes_no:
 		while True:
 			if len(message) > 0 and message[len(message)-1] == " ": message = message[:-1]
@@ -24,6 +25,42 @@ def input(message, yes_no=False):
 			else: break
 		return _input_(message+": ")
 
+# execute.
+def execute(
+	# the command in str format.
+	command="ls .",
+	# joiner for when command is in list format.
+	joiner="\n",
+):
+	path = f"/tmp/tmp_script_{Formats.String('').generate()}"
+	if isinstance(command, list):
+		command = Files.Array(array=command).string(joiner=joiner)
+	Files.save(path, command)
+	try:
+		proc = subprocess.run(
+		    ["sh", path],
+			check=True,
+			capture_output=True,
+			text=True,
+		)
+	except subprocess.CalledProcessError as error:
+		error_, output = error.stderr, error.output
+		if isinstance(error_, bytes): error_ = error_.decode()
+		if isinstance(output, bytes): output = error_.decode()
+		return r3sponse.error_response(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
+	error_, output = proc.stderr, proc.stdout
+	if isinstance(error_, bytes): error_ = error_.decode()
+	if isinstance(output, bytes): output = error_.decode()
+	if error_ != "":
+		return r3sponse.error_response(f"Failed to execute command ({command}), (output: {output}), (error: {error_}).")
+	if len(output) > 0 and output[len(output)-1] == "\n": output = output[:-1]
+	Files.delete(path)
+	return r3sponse.success_response(f"Succesfully executed command ({command}), (output: {output}), (error: {error_}).", {
+		"output":output,
+		"pid":process.pid,
+		"process":proc,
+	})
+
 # the loader object class.
 class Loader(threading.Thread):
 	def __init__(self, message, autostart=True, log_level=0, interactive=True):
@@ -32,15 +69,15 @@ class Loader(threading.Thread):
 		self.last_message = str(self.message)
 		self.log_level = log_level
 		self.interactive = interactive
-		if self.interactive and autostart and self.log_level >= 0: 
-			#self.start()
-			try:
-				self.start()
-			except KeyboardInterrupt as e:
-				self.stop(success=False)
-				raise KeyboardInterrupt(f"{e}")
-		elif not self.interactive:
-			print(self.message+".")
+		if autostart and self.log_level >= 0: 
+			if self.interactive:
+				try:
+					self.start()
+				except KeyboardInterrupt as e:
+					self.stop(success=False)
+					raise KeyboardInterrupt(f"{e}")
+			else:
+				print(self.message+".")
 	def run(self):
 		if self.log_level >= 0: 
 			self.running = True
@@ -87,7 +124,7 @@ class Loader(threading.Thread):
 						print(f"{message}. done")
 					else:
 						print(f"{message}. {color.red}failed{color.end}")
-	def mark(self, old_message=None, new_message=None, success=True, response=None):
+	def mark(self, new_message=None, old_message=None, success=True, response=None):
 		if self.log_level >= 0: 
 			if response != None:
 				if response["error"] == None:
