@@ -7,7 +7,7 @@ from syst3m.classes.config import *
 # pip imports.
 if OS in ["linux"]:
 	import pyautogui
-elif OS in ["osx"]:
+elif OS in ["macos"]:
 	a=1
 
 # the screen object class.
